@@ -166,7 +166,8 @@ class RestInput(InputChannel):
                     )
                 except CancelledError:
                     logger.error(
-                        f"Message handling timed out for " f"user message '{text}'."
+                        f"Message handling timed out for user message '{text}'.",
+                        exc_info=True,
                     )
                 except Exception:
                     logger.exception(
