@@ -16,9 +16,11 @@ DEFAULT_CORE_FALLBACK_THRESHOLD = 0.3
 
 DEFAULT_MAX_HISTORY = None  # Core policy history is unbounded by default.
 
+DEFAULT_RESPONSE_TIMEOUT = 60 * 60  # 1 hour
+
 DEFAULT_REQUEST_TIMEOUT = 60 * 5  # 5 minutes
 
-DEFAULT_RESPONSE_TIMEOUT = 60 * 60  # 1 hour
+DEFAULT_STREAM_READING_TIMEOUT = 10  # in seconds
 
 DEFAULT_LOCK_LIFETIME = 60  # in seconds
 
@@ -74,3 +76,6 @@ POLICY_MAX_HISTORY = "max_history"
 DEFAULT_PROTOCOL = "UDP"
 DEFAULT_SYSLOG_HOST = "localhost"
 DEFAULT_SYSLOG_PORT = 514
+
+COMPRESS_ACTION_SERVER_REQUEST_ENV_NAME = "COMPRESS_ACTION_SERVER_REQUEST"
+DEFAULT_COMPRESS_ACTION_SERVER_REQUEST = False
