@@ -116,12 +116,12 @@ class SingleStateFeaturizer:
         if attribute in {INTENT, ACTION_NAME}:
             return {sub_state[attribute]: 1}  # type: ignore[dict-item]
         elif attribute == ENTITIES:
-            return {entity: 1 for entity in sub_state.get(ENTITIES, [])}
+            return {entity: 1 for entity in sub_state.get(ENTITIES, [])}  # type: ignore[misc]  # noqa: E501
         elif attribute == ACTIVE_LOOP:
             return {sub_state["name"]: 1}  # type: ignore[dict-item]
         elif attribute == SLOTS:
             return {
-                f"{slot_name}_{i}": value
+                f"{slot_name}_{i}": value  # type: ignore[misc]
                 for slot_name, slot_as_feature in sub_state.items()
                 for i, value in enumerate(slot_as_feature)
             }
