@@ -36,8 +36,9 @@ class TemplatedNaturalLanguageGenerator(NaturalLanguageGenerator):
             value = constraint["value"]
             filled_slots_value = filled_slots.get(name)
             if isinstance(filled_slots_value, str) and isinstance(value, str):
-                return filled_slots_value.casefold() == value.casefold()
-            if filled_slots.get(name) != value:
+                if filled_slots_value.casefold() != value.casefold():
+                    return False
+            elif filled_slots_value != value:
                 return False
 
         return True
