@@ -4,9 +4,13 @@ import dataclasses
 from abc import ABC, abstractmethod
 from dataclasses import dataclass, field
 import logging
-from typing import Any, Callable, Dict, List, Optional, Text, Type, Tuple
+from typing import Any, Callable, Dict, List, Optional, Text, Type, Tuple, Union
 
-from rasa.engine.exceptions import GraphComponentException, GraphSchemaException
+from rasa.engine.exceptions import (
+    GraphComponentException,
+    GraphRunError,
+    GraphSchemaException,
+)
 import rasa.shared.utils.common
 import rasa.utils.common
 from rasa.engine.storage.resource import Resource
@@ -425,22 +429,41 @@ class GraphNode:
         return Resource(self._node_name)
 
     def __call__(
-        self, *inputs_from_previous_nodes: Tuple[Text, Any]
+        self, *inputs_from_previous_nodes: Union[Tuple[Text, Any], Text]
     ) -> Tuple[Text, Any]:
         """Calls the `GraphComponent` run method when the node executes in the graph.
 
         Args:
             *inputs_from_previous_nodes: The output of all parent nodes. Each is a
                 dictionary with a single item mapping the node's name to its output.
+                If the node couldn't be resolved and has no output, the node name is
+                provided instead of a tuple.
 
         Returns:
             The node name and its output.
         """
-        received_inputs: Dict[Text, Any] = dict(inputs_from_previous_nodes)
+        # filter out arguments that dask couldn't lookup
+        received_inputs: Dict[Text, Any] = {}
+        for i in inputs_from_previous_nodes:
+            if isinstance(i, tuple):
+                node_name, node_output = i
+                received_inputs[node_name] = node_output
+            else:
+                logger.warning(
+                    f"Node '{i}' was not resolved, there is no putput. "
+                    f"Another component should have provided this as an "
+                    f"output."
+                )
 
         kwargs = {}
-        for input_name, input_node in self._inputs.items():
-            kwargs[input_name] = received_inputs[input_node]
+        for input_name, input_provider_node_name in self._inputs.items():
+            if input_provider_node_name not in received_inputs:
+                raise GraphRunError(
+                    f"Missing input to run node '{self._node_name}'. "
+                    f"Expected input '{input_provider_node_name}' to "
+                    f"provide parameter '{input_name}'."
+                )
+            kwargs[input_name] = received_inputs[input_provider_node_name]
 
         input_hook_outputs = self._run_before_hooks(kwargs)
 
@@ -553,6 +576,7 @@ class GraphModelConfiguration:
     train_schema: GraphSchema
     predict_schema: GraphSchema
     training_type: TrainingType
+    assistant_id: Optional[Text]
     language: Optional[Text]
     core_target: Optional[Text]
     nlu_target: Optional[Text]
