@@ -101,7 +101,7 @@ class YAMLStoryReader(StoryReader):
         Returns:
             `StoryStep`s read from `filename`.
         """
-        self.source_name = filename
+        self.source_name = str(filename)
         try:
             return self.read_from_string(
                 rasa.shared.utils.io.read_file(
@@ -110,7 +110,7 @@ class YAMLStoryReader(StoryReader):
                 skip_validation,
             )
         except YamlException as e:
-            e.filename = filename
+            e.filename = str(filename)
             raise e
 
     def read_from_string(
@@ -648,7 +648,8 @@ class YAMLStoryReader(StoryReader):
                 f"Failed to parse arguments in line '{match.string}'. "
                 f"Failed to interpret some parts. "
                 f"Make sure your regex string is in the following format:"
-                f"\<intent_name>@<confidence-value><dictionary of entities> "  # noqa:  W505, W605, E501
+                f"{INTENT_MESSAGE_PREFIX}"
+                f"<intent_name>@<confidence-value><dictionary of entities> "
                 f"Continuing without {match.group('rest')}. "
             )
 
