@@ -54,6 +54,7 @@ class Message:
         self.features = features if features else []
 
         self.data.update(**kwargs)
+        self._cached_fingerprint: Optional[Text] = None
 
         if output_properties:
             self.output_properties = output_properties
@@ -62,8 +63,10 @@ class Message:
         self.output_properties.add(TEXT)
 
     def add_features(self, features: Optional["Features"]) -> None:
+        """Add more vectorized features to the message."""
         if features is not None:
             self.features.append(features)
+        self._cached_fingerprint = None
 
     def add_diagnostic_data(self, origin: Text, data: Dict[Text, Any]) -> None:
         """Adds diagnostic data from the `origin` component.
@@ -80,6 +83,7 @@ class Message:
             )
         self.data.setdefault(DIAGNOSTIC_DATA, {})
         self.data[DIAGNOSTIC_DATA][origin] = data
+        self._cached_fingerprint = None
 
     def set(self, prop: Text, info: Any, add_to_output: bool = False) -> None:
         """Sets the message's property to the given value.
@@ -92,8 +96,10 @@ class Message:
         self.data[prop] = info
         if add_to_output:
             self.output_properties.add(prop)
+        self._cached_fingerprint = None
 
     def get(self, prop: Text, default: Optional[Any] = None) -> Any:
+        """Retrieve message property."""
         return self.data.get(prop, default)
 
     def as_dict_nlu(self) -> dict:
@@ -143,9 +149,11 @@ class Message:
         Returns:
             Fingerprint of the message.
         """
-        return rasa.shared.utils.io.deep_container_fingerprint(
-            [self.data, self.features]
-        )
+        if self._cached_fingerprint is None:
+            self._cached_fingerprint = rasa.shared.utils.io.deep_container_fingerprint(
+                [self.data, self.features]
+            )
+        return self._cached_fingerprint
 
     @classmethod
     def build(
