@@ -43,7 +43,6 @@ DROP_RATE_DIALOGUE = "drop_rate_dialogue"
 DROP_RATE_LABEL = "drop_rate_label"
 CONSTRAIN_SIMILARITIES = "constrain_similarities"
 
-WEIGHT_SPARSITY = "weight_sparsity"  # Deprecated and superseeded by CONNECTION_DENSITY
 CONNECTION_DENSITY = "connection_density"
 
 EVAL_NUM_EPOCHS = "evaluate_every_number_of_epochs"
@@ -57,6 +56,7 @@ SPARSE_INPUT_DROPOUT = "use_sparse_input_dropout"
 DENSE_INPUT_DROPOUT = "use_dense_input_dropout"
 
 RANKING_LENGTH = "ranking_length"
+RENORMALIZE_CONFIDENCES = "renormalize_confidences"
 MODEL_CONFIDENCE = "model_confidence"
 
 BILOU_FLAG = "BILOU_flag"
@@ -69,7 +69,6 @@ SOFTMAX = "softmax"
 MARGIN = "margin"
 AUTO = "auto"
 INNER = "inner"
-LINEAR_NORM = "linear_norm"
 COSINE = "cosine"
 CROSS_ENTROPY = "cross_entropy"
 
@@ -110,5 +109,7 @@ SEVERITY_KEY = "severity"
 NAME = "name"
 
 TF_DETERMINISTIC_OPS = "TF_DETERMINISTIC_OPS"
+EPOCH_OVERRIDE = "epoch_override"
 
 USE_GPU = "use_gpu"
+RUN_EAGERLY = "run_eagerly"
